@@ -28,12 +28,14 @@
 #'  when they call `make_groups()`.
 #'
 #' @keywords internal
-make_groups <- function(data,
-                        group,
-                        v,
-                        balance = c("groups", "observations", "prop"),
-                        strata = NULL,
-                        ...) {
+make_groups <- function(
+  data,
+  group,
+  v,
+  balance = c("groups", "observations", "prop"),
+  strata = NULL,
+  ...
+) {
   rlang::check_dots_used(call = rlang::caller_env())
   balance <- rlang::arg_match(balance, error_call = rlang::caller_env())
 
@@ -71,11 +73,10 @@ make_groups <- function(data,
   data_ind$..group <- as.character(data_ind$..group)
   keys$..group <- as.character(keys$..group)
 
-  data_ind <- data_ind %>%
-    full_join(keys, by = "..group") %>%
+  data_ind <- data_ind |>
+    full_join(keys, by = "..group") |>
     arrange(..index)
   split_unnamed(data_ind$..index, data_ind$..folds)
-
 }
 
 balance_groups <- function(data_ind, v, strata = NULL, ...) {
@@ -174,14 +175,13 @@ balance_observations <- function(data_ind, v, strata = NULL, ...) {
     balance_observations_helper,
     v = v,
     target_per_fold = target_per_fold
-  ) %>%
+  ) |>
     list_rbind()
 
   collapse_groups(freq_table, data_ind, v)
 }
 
 balance_observations_helper <- function(data_split, v, target_per_fold) {
-
   n_obs <- nrow(data_split)
   # Create a frequency table counting how many of each group are in the data:
   freq_table <- vec_count(data_split$..group, sort = "location")
@@ -200,13 +200,13 @@ balance_observations_helper <- function(data_split, v, target_per_fold) {
     next_size <- freq_table[next_row, ]$count
 
     # Calculate which fold to assign this new row into:
-    group_breakdown <- freq_table %>%
+    group_breakdown <- freq_table |>
       # The only NA column in freq_table should be assignment
       # So this should only drop un-assigned groups:
-      stats::na.omit() %>%
+      stats::na.omit() |>
       # Group by fold assignments and count data in each fold:
-      dplyr::group_by(.data$assignment) %>%
-      dplyr::summarise(count = sum(.data$count), .groups = "drop") %>%
+      dplyr::group_by(.data$assignment) |>
+      dplyr::summarise(count = sum(.data$count), .groups = "drop") |>
       # Calculate...:
       dplyr::mutate(
         # The proportion of data in each fold so far,
@@ -229,7 +229,14 @@ balance_observations_helper <- function(data_split, v, target_per_fold) {
   freq_table
 }
 
-balance_prop <- function(prop, data_ind, v, replace = FALSE, strata = NULL, ...) {
+balance_prop <- function(
+  prop,
+  data_ind,
+  v,
+  replace = FALSE,
+  strata = NULL,
+  ...
+) {
   rlang::check_dots_empty()
 
   # This is the core difference between stratification and not:
@@ -252,14 +259,13 @@ balance_prop <- function(prop, data_ind, v, replace = FALSE, strata = NULL, ...)
     prop = prop,
     v = v,
     replace = replace
-  ) %>%
+  ) |>
     list_rbind()
 
   collapse_groups(freq_table, data_ind, v)
 }
 
 balance_prop_helper <- function(prop, data_ind, v, replace) {
-
   freq_table <- vec_count(data_ind$..group, sort = "location")
 
   # Calculate how many groups to sample each iteration
@@ -285,7 +291,7 @@ balance_prop_helper <- function(prop, data_ind, v, replace) {
       out$assignment <- x
       out
     }
-  ) %>%
+  ) |>
     list_rbind()
 }
 
