@@ -205,14 +205,16 @@ NULL
 
 #' @export
 #' @rdname slide-resampling
-sliding_window <- function(data,
-                           ...,
-                           lookback = 0L,
-                           assess_start = 1L,
-                           assess_stop = 1L,
-                           complete = TRUE,
-                           step = 1L,
-                           skip = 0L) {
+sliding_window <- function(
+  data,
+  ...,
+  lookback = 0L,
+  assess_start = 1L,
+  assess_stop = 1L,
+  complete = TRUE,
+  step = 1L,
+  skip = 0L
+) {
   rlang::check_dots_empty()
 
   if (!is.data.frame(data)) {
@@ -226,7 +228,9 @@ sliding_window <- function(data,
   skip <- check_skip(skip)
 
   if (assess_start > assess_stop) {
-    cli_abort("{.arg assess_start} must be less than or equal to {.arg assess_stop}.")
+    cli_abort(
+      "{.arg assess_start} must be less than or equal to {.arg assess_stop}."
+    )
   }
 
   seq <- vctrs::vec_seq_along(data)
@@ -261,7 +265,7 @@ sliding_window <- function(data,
 
   splits <- purrr::map(
     indices,
-    ~ make_splits(.x, data = data, class = "sliding_window_split")
+    \(.x) make_splits(.x, data = data, class = "sliding_window_split")
   )
 
   ids <- names0(length(indices), prefix = "Slice")
@@ -287,15 +291,17 @@ sliding_window <- function(data,
 
 #' @export
 #' @rdname slide-resampling
-sliding_index <- function(data,
-                          index,
-                          ...,
-                          lookback = 0L,
-                          assess_start = 1L,
-                          assess_stop = 1L,
-                          complete = TRUE,
-                          step = 1L,
-                          skip = 0L) {
+sliding_index <- function(
+  data,
+  index,
+  ...,
+  lookback = 0L,
+  assess_start = 1L,
+  assess_stop = 1L,
+  complete = TRUE,
+  step = 1L,
+  skip = 0L
+) {
   rlang::check_dots_empty()
 
   if (!is.data.frame(data)) {
@@ -347,7 +353,7 @@ sliding_index <- function(data,
 
   splits <- purrr::map(
     indices,
-    ~ make_splits(.x, data = data, class = "sliding_index_split")
+    \(.x) make_splits(.x, data = data, class = "sliding_index_split")
   )
 
   ids <- names0(length(indices), prefix = "Slice")
@@ -374,18 +380,20 @@ sliding_index <- function(data,
 
 #' @export
 #' @rdname slide-resampling
-sliding_period <- function(data,
-                           index,
-                           period,
-                           ...,
-                           lookback = 0L,
-                           assess_start = 1L,
-                           assess_stop = 1L,
-                           complete = TRUE,
-                           step = 1L,
-                           skip = 0L,
-                           every = 1L,
-                           origin = NULL) {
+sliding_period <- function(
+  data,
+  index,
+  period,
+  ...,
+  lookback = 0L,
+  assess_start = 1L,
+  assess_stop = 1L,
+  complete = TRUE,
+  step = 1L,
+  skip = 0L,
+  every = 1L,
+  origin = NULL
+) {
   rlang::check_dots_empty()
 
   if (!is.data.frame(data)) {
@@ -398,7 +406,9 @@ sliding_period <- function(data,
   step <- check_step(step)
 
   if (assess_start > assess_stop) {
-    cli_abort("{.arg assess_start} must be less than or equal to {.arg assess_stop}.")
+    cli_abort(
+      "{.arg assess_start} must be less than or equal to {.arg assess_stop}."
+    )
   }
 
   index <- rlang::enexpr(index)
@@ -449,7 +459,7 @@ sliding_period <- function(data,
 
   splits <- purrr::map(
     indices,
-    ~ make_splits(.x, data = data, class = "sliding_period_split")
+    \(.x) make_splits(.x, data = data, class = "sliding_period_split")
   )
 
   ids <- names0(length(indices), prefix = "Slice")
