@@ -1,5 +1,5 @@
 library(dplyr)
-skip_if_not(rlang::is_installed("withr"))
+skip_if_not_installed("withr")
 # ------------------------------------------------------------------------------
 # dplyr_reconstruct()
 
@@ -102,6 +102,7 @@ test_that("row slicing and duplicating any rows removes the rset subclass", {
   subclasses$validation_split <- NULL
   subclasses$validation_time_split <- NULL
   subclasses$group_validation_split <- NULL
+  subclasses$validation_set <- NULL
 
   for (x in subclasses) {
     loc <- seq_len(nrow(x))
@@ -251,7 +252,6 @@ test_that("slice() drops rset class when rows are modified", {
 
 test_that("slice() keeps rset class when rows are untouched", {
   for (x in rset_subclasses) {
-    expect_s3_class_rset(slice(x))
     expect_s3_class_rset(slice(x, seq_len(nrow(x))))
   }
 })
@@ -272,7 +272,11 @@ test_that("summarise() always drops the rset class", {
 test_that("group_by() always returns a bare grouped-df or bare tibble", {
   for (x in rset_subclasses) {
     expect_s3_class_bare_tibble(group_by(x))
-    expect_s3_class(group_by(x, splits), c("grouped_df", "tbl_df", "tbl", "data.frame"), exact = TRUE)
+    expect_s3_class(
+      group_by(x, splits),
+      c("grouped_df", "tbl_df", "tbl", "data.frame"),
+      exact = TRUE
+    )
   }
 })
 
@@ -325,7 +329,13 @@ test_that("left_join() can keep rset class if rset structure is intact", {
 test_that("left_join() can lose rset class if rows are added", {
   for (x in rset_subclasses) {
     y <- tibble(id = x$id[[1]], x = 1:2)
-    expect_s3_class_bare_tibble(left_join(x, y, by = "id"))
+    expect_s3_class_bare_tibble(left_join(
+      x,
+      y,
+      by = "id",
+      multiple = "all",
+      relationship = "many-to-many"
+    ))
   }
 })
 
@@ -347,7 +357,13 @@ test_that("right_join() can keep rset class if rset structure is intact", {
 test_that("right_join() can lose rset class if rows are added", {
   for (x in rset_subclasses) {
     y <- tibble(id = x$id[[1]], x = 1:2)
-    expect_s3_class_bare_tibble(right_join(x, y, by = "id"))
+    expect_s3_class_bare_tibble(right_join(
+      x,
+      y,
+      by = "id",
+      multiple = "all",
+      relationship = "many-to-many"
+    ))
   }
 })
 
@@ -355,7 +371,7 @@ test_that("right_join() restores to the type of first input", {
   for (x in rset_subclasses) {
     y <- tibble(id = x$id[[1]], x = 1)
     # technically rset structure is intact, but `y` is a bare tibble!
-    expect_s3_class_bare_tibble(right_join(y, x, by = "id"))
+    expect_s3_class_bare_tibble(right_join(y, x, by = "id", multiple = "all"))
   }
 })
 
