@@ -18,7 +18,8 @@ test_that("repeated cv", {
 test_that("nested cv", {
   expect_snapshot(
     labels(
-      nested_cv(mtcars,
+      nested_cv(
+        mtcars,
         outside = vfold_cv(v = 3),
         inside = bootstraps(times = 5)
       )
@@ -32,39 +33,39 @@ test_that("adding labels", {
   car_folds <- vfold_cv(mtcars, repeats = 3)
 
   res <-
-    analysis(car_folds$splits[[1]]) %>%
+    analysis(car_folds$splits[[1]]) |>
     add_resample_id(car_folds$splits[[1]])
   expect_equal(colnames(res), c(colnames(mtcars), "id", "id2"))
 
   car_bt <- bootstraps(mtcars)
 
-  res <- analysis(car_bt$splits[[1]]) %>%
+  res <- analysis(car_bt$splits[[1]]) |>
     add_resample_id(car_bt$splits[[1]])
 
   expect_equal(colnames(res), c(colnames(mtcars), "id"))
 
-  res <- analysis(car_bt$splits[[1]]) %>%
+  res <- analysis(car_bt$splits[[1]]) |>
     add_resample_id(car_bt$splits[[1]], TRUE)
 
   expect_equal(colnames(res), c(colnames(mtcars), ".id"))
 
   expect_snapshot(error = TRUE, {
-    analysis(car_folds$splits[[1]]) %>%
+    analysis(car_folds$splits[[1]]) |>
       add_resample_id(car_folds$splits[[1]], 7)
   })
   expect_snapshot(error = TRUE, {
-    analysis(car_folds$splits[[1]]) %>%
+    analysis(car_folds$splits[[1]]) |>
       add_resample_id(car_folds$splits[[1]], c(TRUE, TRUE))
   })
 
   expect_snapshot(error = TRUE, {
-    analysis(car_folds$splits[[1]]) %>%
+    analysis(car_folds$splits[[1]]) |>
       add_resample_id(car_folds$splits)
   })
 
   expect_snapshot(error = TRUE, {
-    analysis(car_folds$splits[[1]]) %>%
-      as.matrix() %>%
+    analysis(car_folds$splits[[1]]) |>
+      as.matrix() |>
       add_resample_id(car_folds$splits[[1]])
   })
 })
